#ifndef _strlcpy_h_ 
#define _strlcpy_h_

#ifdef __cplusplus
extern "C" {
#endif

size_t strlcpy(char *dst, const char *src, size_t dstsize);

#ifdef __cplusplus
}
#endif
#endif	/* _strlcpy_h_ */
